gmod_evaluate.Rd
runs the decision tree or markov model and returns the outcomes either traces and summary outcomes
gmod_evaluate(x, ...)
a matrix containing the numerical gmod object from the gmod_parse() function
gmod object
print("see vignettes: vignettes(package='gmod')") #> [1] "see vignettes: vignettes(package='gmod')"