runs the decision tree or markov model and returns the outcomes either traces and summary outcomes

gmod_gen_model_function(x, ...)

Arguments

model_num_struc

a matrix containing the numerical gmod object from the gmod_parse() function

Value

model_struc and generates model function code

Examples

print("see vignettes: vignettes(package='gmod')")
#> [1] "see vignettes: vignettes(package='gmod')"