parses the string formulae and computes the numerical outcomes

gmod_parse(x, ...)

Arguments

gmod_obj

a gmod object containing the equations for the Markov model

params

a list containing the model parameters

Value

a nuemerical gmod object structure

Examples

print("See Vignettes")
#> [1] "See Vignettes"