gmod_parse.Rd
parses the string formulae and computes the numerical outcomes
gmod_parse(x, ...)
a gmod object containing the equations for the Markov model
a list containing the model parameters
a nuemerical gmod object structure
print("See Vignettes") #> [1] "See Vignettes"